use serde::Serialize;
use all4art_authservice_cqrs::query_results::LoginQueryResult;

#[derive(Serialize)]
pub struct TokenDto { 
    pub jwt: String
}

impl TokenDto { 
    pub fn from_query_result(result: LoginQueryResult) -> Self{
       TokenDto {jwt: result.token().value().clone()} 
    }
}
